@@ -23,9 +23,6 @@
 
 #include <QByteArray>
 
-#include <ktexteditor/smartrange.h>
-#include <ktexteditor/smartinterface.h>
-
 #include <language/duchain/stringhelpers.h>
 #include <language/duchain/aliasdeclaration.h>
 #include <language/duchain/types/integraltype.h>
@@ -48,7 +45,6 @@
 #include "../declarations/namespacealiasdeclaration.h"
 #include "expressionvisitor.h"
 
-using namespace KTextEditor;
 using namespace KDevelop;
 
 namespace Php
@@ -116,14 +112,15 @@ void DeclarationBuilder::getVariableIdentifier(VariableAst* node,
     }
 }
 
-KDevelop::ReferencedTopDUContext DeclarationBuilder::build(const KDevelop::IndexedString& url, Php::AstNode* node,
-        KDevelop::ReferencedTopDUContext updateContext, bool useSmart)
+ReferencedTopDUContext DeclarationBuilder::build(const IndexedString& url, AstNode* node,
+        ReferencedTopDUContext updateContext)
 {
     //Run DeclarationBuilder twice, to find uses of declarations that are
     //declared after the use. ($a = new Foo; class Foo {})
     {
-        PreDeclarationBuilder prebuilder(&m_types, &m_functions, &m_namespaces, &m_upcomingClassVariables, editor());
-        updateContext = prebuilder.build(url, node, updateContext, useSmart);
+        PreDeclarationBuilder prebuilder(&m_types, &m_functions, &m_namespaces,
+                                         &m_upcomingClassVariables, m_editor);
+        updateContext = prebuilder.build(url, node, updateContext);
         m_actuallyRecompiling = prebuilder.didRecompile();
     }
 
@@ -136,7 +133,7 @@ KDevelop::ReferencedTopDUContext DeclarationBuilder::build(const KDevelop::Index
         m_reportErrors = ICore::self()->languageController()->completionSettings()->highlightSemanticProblems();
     }
 
-    return ContextBuilderBase::build(url, node, updateContext, useSmart);
+    return ContextBuilderBase::build(url, node, updateContext);
 }
 
 void DeclarationBuilder::startVisiting(AstNode* node)
@@ -158,7 +155,7 @@ void DeclarationBuilder::closeDeclaration()
     DeclarationBuilderBase::closeDeclaration();
 }
 
-void DeclarationBuilder::classContextOpened(KDevelop::DUContext* context)
+void DeclarationBuilder::classContextOpened(DUContext* context)
 {
     DUChainWriteLocker lock(DUChain::lock());
     currentDeclaration()->setInternalContext(context);
@@ -252,7 +249,7 @@ bool DeclarationBuilder::isBaseMethodRedeclaration(const IdentifierPair &ids, Cl
 
 void DeclarationBuilder::visitClassStatement(ClassStatementAst *node)
 {
-    setComment(formatComment(node, editor()));
+    setComment(formatComment(node, m_editor));
     if (node->methodName) {
         //method declaration
 
@@ -403,9 +400,9 @@ void DeclarationBuilder::openClassMemberDeclaration(AstNode* node, const Qualifi
 
     // dirty hack: declarations of class members outside the class context would
     //             make the class context encompass the newRange. This is not what we want.
-    SimpleRange oldRange = currentContext()->range();
+    RangeInRevision oldRange = currentContext()->range();
 
-    SimpleRange newRange = editorFindRange(node, node);
+    RangeInRevision newRange = editorFindRange(node, node);
     openDefinition<ClassMemberDeclaration>(name, newRange);
 
     ClassMemberDeclaration* dec = dynamic_cast<ClassMemberDeclaration*>(currentDeclaration());
@@ -471,14 +468,14 @@ void DeclarationBuilder::declareClassMember(DUContext *parentCtx, AbstractType::
 
     // this member should be public and non-static
     m_currentModifers = ModifierPublic;
-    injectContext(editor()->smart(), parentCtx);
+    injectContext(parentCtx);
     openClassMemberDeclaration(node, identifier);
     m_currentModifers = 0;
     //own closeDeclaration() that doesn't use lastType()
     currentDeclaration()->setType(type);
     eventuallyAssignInternalContext();
     DeclarationBuilderBase::closeDeclaration();
-    closeInjectedContext(editor()->smart());
+    closeInjectedContext();
 }
 
 void DeclarationBuilder::visitConstantDeclaration(ConstantDeclarationAst *node)
@@ -511,7 +508,6 @@ void DeclarationBuilder::visitConstantDeclaration(ConstantDeclarationAst *node)
                 case IntegralType::TypeFloat:
                 case IntegralType::TypeInt:
                 case IntegralType::TypeString:
-                case IntegralType::TypeNull:
                     badType = false;
                     break;
                 default:
@@ -530,7 +526,7 @@ void DeclarationBuilder::visitParameter(ParameterAst *node)
     AbstractFunctionDeclaration* funDec = dynamic_cast<AbstractFunctionDeclaration*>(currentDeclaration());
     Q_ASSERT(funDec);
     if (node->defaultValue) {
-        QString symbol = editor()->parseSession()->symbol(node->defaultValue);
+        QString symbol = m_editor->parseSession()->symbol(node->defaultValue);
         funDec->addDefaultParameter(IndexedString(symbol));
         if ( node->parameterType && symbol.compare(QLatin1String("null"), Qt::CaseInsensitive) != 0 ) {
             reportError(i18n("Default value for parameters with a class type hint can only be NULL."), node->defaultValue);
@@ -541,7 +537,7 @@ void DeclarationBuilder::visitParameter(ParameterAst *node)
     {
         // create variable declaration for argument
         DUChainWriteLocker lock(DUChain::lock());
-        SimpleRange newRange = editorFindRange(node->variable, node->variable);
+        RangeInRevision newRange = editorFindRange(node->variable, node->variable);
         openDefinition<VariableDeclaration>(identifierForNode(node->variable), newRange);
         currentDeclaration()->setKind(Declaration::Instance);
     }
@@ -655,8 +651,8 @@ void DeclarationBuilder::reportRedeclarationError(Declaration* declaration, AstN
 void DeclarationBuilder::visitOuterTopStatement(OuterTopStatementAst* node)
 {
     //docblock of an AssignmentExpression
-    setComment(formatComment(node, editor()));
-    m_lastTopStatementComment = editor()->parseSession()->docComment(node->startToken);
+    setComment(formatComment(node, m_editor));
+    m_lastTopStatementComment = m_editor->parseSession()->docComment(node->startToken);
 
     DeclarationBuilderBase::visitOuterTopStatement(node);
 }
@@ -775,7 +771,7 @@ void DeclarationBuilder::declareVariable(DUContext* parentCtx, AbstractType::Ptr
         }
     }
 
-    SimpleRange newRange = editorFindRange(node, node);
+    RangeInRevision newRange = editorFindRange(node, node);
 
     VariableDeclaration *dec = openDefinition<VariableDeclaration>(identifier, newRange);
     dec->setKind(Declaration::Instance);
@@ -847,11 +843,11 @@ void DeclarationBuilder::visitFunctionCall(FunctionCallAst* node)
     {
         FunctionType::Ptr oldFunction = m_currentFunctionType;
 
-        Declaration* dec = 0;
+        DeclarationPointer dec;
         if ( node->stringFunctionName ) {
             dec = findDeclarationImport(FunctionDeclarationType, node->stringFunctionName);
         } else if ( node->stringFunctionNameOrClass ) {
-            id = identifierForNamespace(node->stringFunctionNameOrClass, editor());
+            id = identifierForNamespace(node->stringFunctionNameOrClass, m_editor);
             dec = findDeclarationImport(FunctionDeclarationType, id, node->stringFunctionNameOrClass);
         } else {
             ///TODO: node->varFunctionName
@@ -877,18 +873,17 @@ void DeclarationBuilder::visitFunctionCall(FunctionCallAst* node)
             //find name of the constant (first argument of the function call)
             CommonScalarAst* scalar = findCommonScalar(node->stringParameterList->parametersSequence->at(0)->element);
             if (scalar && scalar->string != -1) {
-                QString constant = editor()->parseSession()->symbol(scalar->string);
+                QString constant = m_editor->parseSession()->symbol(scalar->string);
                 constant = constant.mid(1, constant.length() - 2);
-                SimpleRange newRange = editorFindRange(scalar, scalar);
+                RangeInRevision newRange = editorFindRange(scalar, scalar);
                 DUChainWriteLocker lock(DUChain::lock());
-                LockedSmartInterface iface = editor()->smart();
                 // find fitting context to put define in,
                 // pick first namespace or global context otherwise
                 DUContext* ctx = currentContext();
                 while (ctx->type() != DUContext::Namespace && ctx->parentContext()) {
                     ctx = ctx->parentContext();
                 }
-                injectContext(iface, ctx); //constants are always global
+                injectContext(ctx); //constants are always global
                 QualifiedIdentifier identifier(constant);
                 isGlobalRedeclaration(identifier, scalar, ConstantDeclarationType);
                 openDefinition<Declaration>(identifier, newRange);
@@ -896,7 +891,7 @@ void DeclarationBuilder::visitFunctionCall(FunctionCallAst* node)
                 Q_ASSERT(lastType());
                 lastType()->setModifiers(lastType()->modifiers() | AbstractType::ConstModifier);
                 closeDeclaration();
-                closeInjectedContext(iface);
+                closeInjectedContext();
             }
         }
     }
@@ -1028,7 +1023,7 @@ void DeclarationBuilder::visitStatement(StatementAst* node)
 
     if (node->foreachVariable) {
         DUChainWriteLocker lock(DUChain::lock());
-        SimpleRange newRange = editorFindRange(node->foreachVariable->variable, node->foreachVariable->variable);
+        RangeInRevision newRange = editorFindRange(node->foreachVariable->variable, node->foreachVariable->variable);
         openDefinition<VariableDeclaration>(identifierForNode(node->foreachVariable->variable), newRange);
         currentDeclaration()->setKind(Declaration::Instance);
         closeDeclaration();
@@ -1036,7 +1031,7 @@ void DeclarationBuilder::visitStatement(StatementAst* node)
 
     if (node->foreachVarAsVar) {
         DUChainWriteLocker lock(DUChain::lock());
-        SimpleRange newRange = editorFindRange(node->foreachVarAsVar->variable, node->foreachVarAsVar->variable);
+        RangeInRevision newRange = editorFindRange(node->foreachVarAsVar->variable, node->foreachVarAsVar->variable);
         openDefinition<VariableDeclaration>(identifierForNode(node->foreachVarAsVar->variable), newRange);
         currentDeclaration()->setKind(Declaration::Instance);
         closeDeclaration();
@@ -1044,7 +1039,7 @@ void DeclarationBuilder::visitStatement(StatementAst* node)
 
     if (node->foreachExprAsVar) {
         DUChainWriteLocker lock(DUChain::lock());
-        SimpleRange newRange = editorFindRange(node->foreachExprAsVar, node->foreachExprAsVar);
+        RangeInRevision newRange = editorFindRange(node->foreachExprAsVar, node->foreachExprAsVar);
         openDefinition<VariableDeclaration>(identifierForNode(node->foreachExprAsVar), newRange);
         currentDeclaration()->setKind(Declaration::Instance);
         closeDeclaration();
@@ -1057,8 +1052,8 @@ void DeclarationBuilder::visitStaticVar(StaticVarAst* node)
     DeclarationBuilderBase::visitStaticVar(node);
 
     DUChainWriteLocker lock(DUChain::lock());
-    SimpleRange newRange = editorFindRange(node->var, node->var);
-    openDefinition<VariableDeclaration>(identifierForNode(node->var), newRange);
+    openDefinition<VariableDeclaration>(identifierForNode(node->var),
+                                        editorFindRange(node->var, node->var));
     currentDeclaration()->setKind(Declaration::Instance);
 
     closeDeclaration();
@@ -1081,11 +1076,11 @@ void DeclarationBuilder::visitGlobalVar(GlobalVarAst* node)
             }
         }
         // no existing declaration found, create one
-        Declaration* aliasedDeclaration = findDeclarationImport(GlobalVariableDeclarationType, node->var);
+        DeclarationPointer aliasedDeclaration = findDeclarationImport(GlobalVariableDeclarationType, node->var);
         if (aliasedDeclaration) {
             DUChainWriteLocker lock(DUChain::lock());
-            AliasDeclaration* dec = openDefinition<AliasDeclaration>(id, editor()->findRange(node->var));
-            dec->setAliasedDeclaration(aliasedDeclaration);
+            AliasDeclaration* dec = openDefinition<AliasDeclaration>(id, m_editor->findRange(node->var));
+            dec->setAliasedDeclaration(aliasedDeclaration.data());
             closeDeclaration();
         }
     }
@@ -1096,8 +1091,8 @@ void DeclarationBuilder::visitCatchItem(CatchItemAst *node)
     DeclarationBuilderBase::visitCatchItem(node);
 
     DUChainWriteLocker lock(DUChain::lock());
-    SimpleRange newRange = editorFindRange(node->var, node->var);
-    openDefinition<VariableDeclaration>(identifierForNode(node->var), newRange);
+    openDefinition<VariableDeclaration>(identifierForNode(node->var),
+                                        editorFindRange(node->var, node->var));
     currentDeclaration()->setKind(Declaration::Instance);
     closeDeclaration();
 }
@@ -1105,7 +1100,7 @@ void DeclarationBuilder::visitCatchItem(CatchItemAst *node)
 void DeclarationBuilder::visitUnaryExpression(UnaryExpressionAst* node)
 {
     DeclarationBuilderBase::visitUnaryExpression(node);
-    IndexedString includeFile = getIncludeFileForNode(node, editor());
+    IndexedString includeFile = getIncludeFileForNode(node, m_editor);
     if ( !includeFile.isEmpty() ) {
         DUChainWriteLocker lock;
         TopDUContext* includedCtx = DUChain::self()->chainForDocument(includeFile);
@@ -1116,22 +1111,22 @@ void DeclarationBuilder::visitUnaryExpression(UnaryExpressionAst* node)
 
         QualifiedIdentifier identifier(includeFile.str());
 
-        foreach ( Declaration* dec, includedCtx->findDeclarations(identifier, SimpleCursor(0, 1)) ) {
+        foreach ( Declaration* dec, includedCtx->findDeclarations(identifier, CursorInRevision(0, 1)) ) {
             if ( dec->kind() == Declaration::Import ) {
                 encounter(dec);
                 return;
             }
         }
-        injectContext(editor()->smart(), includedCtx);
-        openDefinition<Declaration>(identifier, SimpleRange(0, 0, 0, 0));
+        injectContext(includedCtx);
+        openDefinition<Declaration>(identifier, RangeInRevision(0, 0, 0, 0));
         currentDeclaration()->setKind(Declaration::Import);
         eventuallyAssignInternalContext();
         DeclarationBuilderBase::closeDeclaration();
-        closeInjectedContext(editor()->smart());
+        closeInjectedContext();
     }
 }
 
-void DeclarationBuilder::openNamespace(NamespaceDeclarationStatementAst* parent, IdentifierAst* node, const IdentifierPair& identifier, const Range& range)
+void DeclarationBuilder::openNamespace(NamespaceDeclarationStatementAst* parent, IdentifierAst* node, const IdentifierPair& identifier, const RangeInRevision& range)
 {
     NamespaceDeclaration* dec = m_namespaces.value(node->string, 0);
     Q_ASSERT(dec);
@@ -1152,17 +1147,17 @@ void DeclarationBuilder::visitUseNamespace(UseNamespaceAst* node)
     if ( !node->aliasIdentifier && node->identifier->namespaceNameSequence->count() == 1 ) {
         reportError(i18n("The use statement with non-compound name '%1' has no effect.",
                          identifierForNode(node->identifier->namespaceNameSequence->front()->element).toString()),
-                    node->identifier, KDevelop::ProblemData::Warning);
+                    node->identifier, ProblemData::Warning);
         return;
     }
     IdentifierAst* idNode = node->aliasIdentifier ? node->aliasIdentifier : node->identifier->namespaceNameSequence->back()->element;
     IdentifierPair id = identifierPairForNode(idNode);
-    SimpleRange range = editor()->findRange(idNode);
     DUChainWriteLocker lock;
-    NamespaceAliasDeclaration* decl = openDefinition<NamespaceAliasDeclaration>(id.second, range);
+    NamespaceAliasDeclaration* decl = openDefinition<NamespaceAliasDeclaration>(id.second,
+                                                                                m_editor->findRange(idNode));
     {
         ///TODO: case insensitive!
-        decl->setImportIdentifier( identifierForNamespace(node->identifier, editor()) );
+        decl->setImportIdentifier( identifierForNamespace(node->identifier, m_editor) );
         decl->setPrettyName( id.first );
         decl->setKind(Declaration::NamespaceAlias);
     }
