@@ -26,7 +26,6 @@
 #include <kcomponentdata.h>
 #include <kpluginfactory.h>
 #include <kpluginloader.h>
-#include <ktexteditor/smartinterface.h>
 #include <KTextEditor/Document>
 
 #include <interfaces/icore.h>
@@ -35,7 +34,6 @@
 #include <interfaces/ilanguage.h>
 #include <interfaces/idocument.h>
 #include <interfaces/iproject.h>
-#include <language/editor/editorintegrator.h>
 #include <language/backgroundparser/backgroundparser.h>
 #include <language/duchain/duchain.h>
 #include <language/duchain/duchainlock.h>
@@ -59,7 +57,7 @@
 using namespace KDevelop;
 
 K_PLUGIN_FACTORY(KDevPhpSupportFactory, registerPlugin<Php::LanguageSupport>();)
-K_EXPORT_PLUGIN(KDevPhpSupportFactory(KAboutData("kdevphpsupport","kdevphp", ki18n("Php Support"), "1.1.2", ki18n("Support for Php Language"), KAboutData::License_GPL)
+K_EXPORT_PLUGIN(KDevPhpSupportFactory(KAboutData("kdevphpsupport","kdevphp", ki18n("Php Support"), "1.1.80", ki18n("Support for Php Language"), KAboutData::License_GPL)
     .addAuthor(ki18n("Milian Wolff"), ki18n("Author"), "mail@milianw.de", "http://milianw.de")
     .addAuthor(ki18n("Niko Sams"), ki18n("Author"), "niko.sams@gmail.com", "http://nikosams.blogspot.com")
 ))
@@ -142,7 +140,7 @@ KDevelop::ILanguage *LanguageSupport::language()
     return core()->languageController()->language(name());
 }
 
-const KDevelop::ICodeHighlighting* LanguageSupport::codeHighlighting() const
+KDevelop::ICodeHighlighting* LanguageSupport::codeHighlighting() const
 {
     return m_highlighting;
 }
@@ -205,6 +203,7 @@ QWidget* LanguageSupport::specialLanguageObjectNavigationWidget(const KUrl& url,
 {
     QPair<QString, SimpleRange> word = wordUnderCursor(url, position);
     if ( isMagicConstant(word) ) {
+        DUChainReadLocker lock;
         return new NavigationWidget(TopDUContextPointer(standardContext(url)), position, word.first);
     }
     return ILanguageSupport::specialLanguageObjectNavigationWidget(url, position);
